import { StoreRegistry } from 'angular-reactive-state/store/store-registry';
import { ReduxDevtoolsExtension } from '../types';
import * as i0 from "@angular/core";
declare global {
    interface Window {
        __REDUX_DEVTOOLS_EXTENSION__: ReduxDevtoolsExtension;
    }
}
export declare class StateDevTools {
    private storeRegistry;
    private devTools;
    private readonly dispatchEvents$;
    private readonly stateHistory;
    private readonly globalState;
    constructor(storeRegistry: StoreRegistry);
    /**
     * Initialize the dev tools which can be used to monitor state changes of the stores.
     */
    init(): void;
    /**
     * Watch all changes which are coming from the monitor of the dev tools extension.
     */
    private watchChangesOfMonitor;
    /**
     * Observes all dispatch events from the devtools extension and
     * updates the respective store with the state which should be replayed.
     *
     * @param event Dispatch event from devtools extension
     * @returns
     */
    private processDispatchEvents;
    /**
     * Watches all state changes which are coming from all stores.
     */
    private watchChangesOfStores;
    /**
     * If the devtools replay some of the old states by time traveling then the references are stored inside of the devtools' state history.
     * Based on the object references the devtools recognize if the state was already processed or if it's a new state change.
     *
     * @param emittedStateFromStore
     * @returns True if state is new to the devtools and false if the state was already processed
     */
    private isStateUnprocessed;
    private changeState;
    static ɵfac: i0.ɵɵFactoryDeclaration<StateDevTools, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<StateDevTools>;
}
